@@ -290,7 +290,7 @@ sub is_in_sync_mask ($$) {
 # by default the version of a module is the fvwm version
 sub version ($) {
 	my $self = shift;
-	return "1.0.4";
+	return "1.0.6a";
 }
 
 sub version_info ($) {
@@ -1156,7 +1156,7 @@ Returns the user data directory, usually ~/.fvwm or set by $FVWM_USERDIR.
 =item B<site_data_dir>
 
 Returns the system-wide data directory, the one configured when fvwm is
-installed. It is also returned by `fvwm-config --fvwm-datadir`.
+installed.
 
 =item B<search_dirs>
 
